@@ -15,26 +15,24 @@ behavior.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-# Load configuration shared with sage.misc.sphinxify
-from sage.misc.sagedoc_conf import *
-
-import sys
+import importlib
 import os
 import re
-import importlib
+import sys
+
 import dateutil.parser
-import sphinx
-import sphinx.ext.intersphinx as intersphinx
+from IPython.lib.lexers import IPyLexer, IPythonConsoleLexer
 from sphinx import highlighting
+from sphinx.ext import intersphinx
 from sphinx.transforms import SphinxTransform
 from sphinx.util.docutils import SphinxDirective
-from IPython.lib.lexers import IPythonConsoleLexer, IPyLexer
-from sage.misc.sagedoc import extlinks
-from sage.env import SAGE_DOC_SRC, SAGE_DOC, PPLPY_DOCS, MATHJAX_DIR
-from sage.misc.latex_macros import sage_mathjax_macros
-from sage.features.sphinx import JupyterSphinx
-from sage.features.all import all_features
+
 import sage.version
+from sage.env import MATHJAX_DIR, PPLPY_DOCS, SAGE_DOC, SAGE_DOC_SRC
+from sage.features.sphinx import JupyterSphinx
+from sage.misc.latex_macros import sage_mathjax_macros
+from sage.misc.sagedoc import extlinks as extlinks  # noqa: PLC0414
+from sage.misc.sagedoc_conf import *  # Load configuration shared with sage.misc.sphinxify
 
 # ---------------------
 # General configuration
@@ -200,8 +198,8 @@ copyright = "2005--{}, The Sage Development Team".format(dateutil.parser.parse(s
 version = sage.version.version
 release = sage.version.version
 
-source_repository = 'https://github.com/sagemath/sage/'
-source_branch = 'develop'
+source_repository = 'https://github.com/passagemath/passagemath/'
+source_branch = 'main'
 
 # The language for content autogenerated by Sphinx. Refer to documentation
 # for a list of supported languages.
@@ -377,8 +375,8 @@ copybutton_only_copy_prompt_lines = True
 
 # https://www.sphinx-doc.org/en/master/usage/extensions/linkcode.html
 def linkcode_resolve(domain, info):
-    import inspect
     from urllib.parse import quote
+
     from sage.misc.sageinspect import sage_getsourcelines
     if domain != 'py':
         return None
@@ -401,7 +399,7 @@ def linkcode_resolve(domain, info):
             anchor = f'#L{lineno}'
         else:
             anchor = ''
-        return f"{source_repository}blob/develop/src/{filename}{anchor}"
+        return f"{source_repository}blob/main/src/{filename}{anchor}"
     return None
 
 
@@ -448,7 +446,7 @@ if github_ref:
     match = re.search(r'refs/pull/(\d+)/merge', github_ref)
     if match:
         pr_number = match.group(1)
-is_for_develop = github_ref.startswith('refs/heads/develop')
+is_for_develop = github_ref.startswith('refs/heads/main')
 is_for_github_pr = github_ref and match and pr_number
 is_stable_release = version.split('.')[-1].isnumeric()
 
@@ -457,13 +455,13 @@ if is_for_develop or is_for_github_pr or not is_stable_release:  # condition for
     # See NETLIFY_ALIAS of the "Deploy to Netlify" step.
     ver = f'<a href="https://doc-develop--sagemath.netlify.app/html/en/index.html">{version}</a>'
     if is_for_github_pr:
-        pr_url = f'https://github.com/sagemath/sage/pull/{pr_number}'
+        pr_url = f'https://github.com/passagemath/passagemath/pull/{pr_number}'
         pr_sha = os.environ.get('PR_SHA', '')
         pr_commit = pr_url + f'/commits/{pr_sha}'
         ver += f' built with GitHub PR <a href="{pr_url}">#{pr_number}</a>' \
                f' on <a href="{pr_commit}">{pr_sha[:7]}</a>' \
                f' [<a href="/changes.html">changes</a>]'
-    banner = f'This is documentation for Sage version {ver} for development purpose.'
+    banner = f'This is documentation for passagemath version {ver} for development purposes.'
     html_theme_options.update({ "announcement": banner })
 
 # The name of the Pygments (syntax highlighting) style to use. This
@@ -690,7 +688,7 @@ def add_page_context(app, pagename, templatename, context, doctree):
     path2 = os.path.join(SAGE_DOC, 'html', 'en')
     relpath = os.path.relpath(path2, path1)
     context['release'] = release
-    context['documentation_title'] = f'Version {release} Documentation'
+    context['documentation_title'] = f'passagemath {release} Documentation'
     context['documentation_root'] = os.path.join(relpath, 'index.html')
     if 'website' in path1:
         context['title'] = 'Documentation'
@@ -699,7 +697,7 @@ def add_page_context(app, pagename, templatename, context, doctree):
     if 'reference' in path1 and not path1.endswith('reference'):
         path2 = os.path.join(SAGE_DOC, 'html', 'en', 'reference')
         relpath = os.path.relpath(path2, path1)
-        context['reference_title'] = f'Version {release} Reference Manual'
+        context['reference_title'] = f'passagemath {release} Reference Manual'
         context['reference_root'] = os.path.join(relpath, 'index.html')
         context['refsub'] = True
         if pagename.startswith('sage/'):
@@ -713,8 +711,8 @@ def add_page_context(app, pagename, templatename, context, doctree):
             f = importlib.import_module(pagename.replace('/','.')).__file__
             suffix = '.py' if not f or f.endswith('.py') else '.pyx'
             context['page_source_suffix'] = suffix
-            context['theme_source_view_link'] = os.path.join(source_repository, 'blob/develop/src', '{filename}')
-            context['theme_source_edit_link'] = os.path.join(source_repository, 'edit/develop/src', '{filename}')
+            context['theme_source_view_link'] = os.path.join(source_repository, 'blob/main/src', '{filename}')
+            context['theme_source_edit_link'] = os.path.join(source_repository, 'edit/main/src', '{filename}')
 
 
 dangling_debug = False
@@ -968,7 +966,10 @@ class SagecodeTransform(SphinxTransform):
         if self.app.builder.tags.has('html') or self.app.builder.tags.has('inventory'):
             for node in list(self.document.findall(nodes.literal_block)):
                 if node.get('language') is None and node.astext().startswith('sage:'):
-                    from docutils.nodes import container as Container, label as Label, literal_block as LiteralBlock, Text
+                    from docutils.nodes import Text
+                    from docutils.nodes import container as Container
+                    from docutils.nodes import label as Label
+                    from docutils.nodes import literal_block as LiteralBlock
                     from sphinx_inline_tabs._impl import TabContainer
                     parent = node.parent
                     index = parent.index(node)
@@ -1028,7 +1029,7 @@ class SagecodeTransform(SphinxTransform):
                             prev_node['classes'].append('with-python-tab')
                     if SAGE_LIVE_DOC == 'yes':
                         # Tab for Jupyter-sphinx cell
-                        from jupyter_sphinx.ast import JupyterCellNode, CellInputNode
+                        from jupyter_sphinx.ast import CellInputNode, JupyterCellNode
                         source = node.rawsource
                         lines = []
                         for line in source.splitlines():
@@ -1111,6 +1112,26 @@ def setup(app):
 # https://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html#tags
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#conf-tags
 # https://github.com/readthedocs/readthedocs.org/issues/4603#issuecomment-1411594800
+def all_features():
+    r"""
+    Yield features used in `.. ONLY:: feature_...` directives
+    """
+    yield JupyterSphinx()
+
+    from sage.features import graphviz, sagemath, sphinx
+    yield graphviz.Graphviz()
+    yield sagemath.sage__symbolic()
+    yield sagemath.sage__libs__cmr()
+    yield sagemath.sage__rings__polynomial__pbori()
+
+    from sage.features import four_ti_2, frobby, gfan, giac, latte
+    yield from four_ti_2.all_features()
+    yield from frobby.all_features()
+    yield from gfan.all_features()
+    yield from giac.all_features()
+    yield from latte.all_features()
+
+
 def feature_tags():
     for feature in all_features():
         if feature.is_present():
